@@ -510,11 +510,4 @@ extern "C" void SAL_CALL component_getImplementationEnvironment(
     *envTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 
-extern "C" ::sal_Bool SAL_CALL component_writeInfo(
-    void * serviceManager, void * registryKey)
-{
-    return ::cppu::component_writeInfoHelper(
-        serviceManager, registryKey, entries);
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
